==> modx-2.0.6-pl-ja.zip: modx-2.0.6-pl-ja/core/lexicon/ja/login.inc.php <==
<?php
/**
 * Login Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['login_activation_key_err'] = '認証キーが一致しません。認証メールを確認し、正しいURLにアクセスしているか確認してください。';
$_lang['login_blocked_admin'] = '管理画面へのアクセスを制限されています。';
$_lang['login_blocked_error'] = '一時的にログインを制限されています。しばらくたってから再度ログインしてください。';
$_lang['login_blocked_ip'] = 'このIPアドレスからのログインは制限されています。';
$_lang['login_blocked_time'] = 'このアカウントではこの時間帯のログインを許可されていません。後ほど、もしくは後日ログインしてください。';
$_lang['login_blocked_too_many_attempts'] = 'ログイン失敗が重なったため、アクセス制限をされています。';
$_lang['login_button'] = 'ログイン';
$_lang['login_cannot_locate_account'] = 'アカウント名が見当たりません。ユーザー名とパスワードを確かめて再ログインをお試しください。';
$_lang['login_copyright'] = '&copy; 2005-' . date('Y') . ' by the <a href="http://modxcms.com/" target="_blank">MODx Team</a>. <strong>MODx</strong>&trade; is licensed under the GPLv2 or later.';
$_lang['login_email_label'] = '登録メールアドレス：';
$_lang['login_err_unknown'] = 'ログイン処理中に不明なエラーが発生しました。';
$_lang['login_forget_your_login'] = 'パスワードを忘れましたか？';
$_lang['login_hostname_error'] = 'ホスト名とIPアドレスが一致しません。';
$_lang['login_message'] = 'MODxへようこそ。ユーザー名とパスワードは大文字・小文字を区別します。';
$_lang['login_modx_support'] = '<p>Supported By:</p><p><a href="http://www.modxcms.com/forums/" target="_blank"><strong>The MODx Community</strong></a></p>';
$_lang['login_password'] = 'パスワード：';
$_lang['login_password_reset_act_sent'] = 'パスワードを再発行し登録されているメールアドレスへ送信しました。メールを確認してください。';
$_lang['login_remember'] = 'ログイン情報を記憶';
$_lang['login_send_activation_email'] = '有効化メールを送信する';
$_lang['login_title'] = 'MODx CMF Manager Login';
$_lang['login_user_err_nf_email'] = '登録されていないメールアドレスです。正しいメールアドレスを入力してください。';
$_lang['login_username'] = 'ユーザー名：';
$_lang['login_username_password_incorrect'] = 'ユーザー名もしくはパスワードが違います。確認して再入力の上、ログインを試してください。';
$_lang['login_user_inactive'] = 'このアカウントは無効になっています。必要な場合はシステム管理者に連絡し、アカウントを有効にしてください。';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/login.inc.php <==
<?php
/**
 * Login English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['login_language'] = '言語';
$_lang['login_activation_key_err'] = '認証キーが一致しません。認証メールを確認し、正しいURLにアクセスしているか確認してください。';
$_lang['login_blocked_admin'] = '管理画面へのアクセスを制限されています。';
$_lang['login_blocked_error'] = '一時的にログインを制限されています。しばらくたってから再度ログインしてください。';
$_lang['login_blocked_ip'] = 'このIPアドレスからのログインは制限されています。';
$_lang['login_blocked_time'] = 'このアカウントではこの時間帯のログインを許可されていません。後ほど、もしくは後日ログインしてください。';
$_lang['login_blocked_too_many_attempts'] = 'ログイン失敗が重なったため、アクセス制限をされています。';
$_lang['login_button'] = 'ログイン';
$_lang['login_cannot_locate_account'] = 'ユーザー名もしくはパスワードが違います。確認して再入力の上、ログインを試してください。';
$_lang['login_copyright'] = '&copy; 2005-2015 by <a href="http://modx.com/about/" target="_blank">MODX, LLC</a>. MODX&trade; Revolution is licensed under the GPLv2 or later.';
$_lang['login_email_label'] = '登録メールアドレス：';
$_lang['login_err_unknown'] = 'ログイン処理中に不明なエラーが発生しました。';
$_lang['login_forget_your_login'] = 'パスワードを忘れましたか？';
$_lang['login_hostname_error'] = 'ホスト名とIPアドレスが一致しません。';
$_lang['login_message'] = 'MODXへようこそ。ユーザー名とパスワードは大文字・小文字を区別します。';
$_lang['login_password'] = 'パスワード：';
$_lang['login_password_reset_act_sent'] = 'パスワードを再発行し登録されているメールアドレスへ送信しました。メールを確認してください。';
$_lang['login_remember'] = 'ログイン情報を記憶';
$_lang['login_send_activation_email'] = '有効化メールを送信する';
$_lang['login_title'] = 'MODX CMF Manager Login';
$_lang['login_user_err_nf_email'] = '登録されていないメールアドレスです。正しいメールアドレスを入力してください。';
$_lang['login_username'] = 'ユーザー名：';
$_lang['login_username_or_email'] = 'Username or Email';
$_lang['login_username_password_incorrect'] = 'ユーザー名もしくはパスワードが違います。確認して再入力の上、ログインを試してください。';
$_lang['login_user_inactive'] = 'このアカウントは無効になっています。必要な場合はシステム管理者に連絡し、アカウントを有効にしてください。';
